# Farosat

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Mirtazayev Asadbek (c) 2022

###     * Install Farosat

```
pip install farosat
```

###  * Chech the version of Farosat

```python
from farosat import get_version

print(farosat.get_version())
```

Output:

```
0.0.3
```